library("ig")

digt(3, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")
digt(3, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")
pigt(0.6758413, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")
qigt(0.5, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")

t   <- seq(0, 4, by = 0.01)
ft1 <- digt(t, 1.0, 4.0, 1.0, "t")
ft2 <- digt(t, 1.0, 4.0, 1.0, "laplace")
ft3 <- digt(t, 1.0, 4.0, 1.0, "logistic")
ft4 <- digt(t, 1.0, 4.0, 1.0, "normal")
ft  <- cbind(ft1, ft2, ft3, ft4)

matplot(t, ft, type = "l", xlim = c(0, 4), ylim = c(0, 1.7), xlab = "t",
  ylab = "f(t)", col = c(4, 3, 2, 1), lty = c(1, 1, 1, 1),
  lwd = c(2, 2, 2, 2))
rect(3, -0.00005, 4, 0.1, border = "orange", lwd = 2)
legend(2.6, 1.7, c("Cauchy", "Laplace", "Logistic", "Normal"),
  col = c(4, 3, 2, 1), lty = c(1, 1, 1, 1), lwd = c(2, 2, 2, 2),
  cex = 1.25)

rigt(n = 6, mu = 1.0, lambda = 1.0, nu = 1.0, kernel = "normal")

data("psi31")
descriptiveSummary(psi31)

histigt(psi31,
  mainTitle = "",
  xLabel = "Lifetimes with maximum stress of 31.000 psi",
  kernel = "t",
  colourHistogram = 4,
  colourBoxPlot = 4)

estimates <- mleigSt(psi31)
estimates
mu     <- estimates$muEstimate
lambda <- estimates$lambdaEstimate
nu     <- estimates$nuOptimal

nus	      <- vector("numeric")
resultsLogLik <- vector("numeric")
for(i in 1:100) {
  nu <- nus[i]
  a <- loglikigt(t, nu, "t")
  resultsLogLik[i] <- a
}

plot(resultsLogLik, type = "p", main = "", xlab = expression(nu),
  ylab = "Log-likelihood", pch = 20, col = 3, lwd = 1.5, axes = FALSE)
box()
axis(1, at = c(1, 20, 40, 60, 80, 100), labels = c(1, 20, 40, 60, 80, 100))
axis(1, at = 7, labels = 7)
axis(2, at = seq(-468, -456, by = 2), labels = seq(-468, -456, by = 2),
  las = 1)
points(7, resultsLogLik[7], pch = 4, lwd = 2.0, col = 2)

diagnosticsigt(psi31, "normal")
title(main = "IG distribution")

diagnosticsigt(psi31, "t", yRange = c(0, 2))
title(main = "IGT-St distribution")

gt(psi31, casesRemoved = 1, kernel = "t")
gt(psi31, casesRemoved = 1, kernel = "normal")

qqigt(psi31, kernel = "t", line = TRUE)
title(main = "IGT-St distribution", cex.main = 1.5)

qqigt(psi31, kernel = "normal", line = TRUE)
title(main = "IG distribution", cex.main = 1.5)

aciigt(psi31, kernel = "normal", confLevel = 95,
  chart = c(120, 150, 2000, 9000), colourRegion = 3,
  colourEstimates = 2)
title(main = "IG distribution", cex.main = 1.5)

aciigt(psi31, kernel = "t", confLevel = 95,
  chart = c(120, 150, 2000, 9000), colourRegion = 3,
  colourEstimates = 2)
title(main = "IGT-St distribution", cex.main = 1.5)

histigt(psi31,
  kernel	  = "t",
  boxPlot	  = FALSE,
  densityLine	  = TRUE,
  mainTitle	  = "",
  xLabel	  = "Lifetimes with maximum stress of 31.000 psi",
  yLabel	  = "Frequency",
  yRange	  = c(0, 0.02),
  colourHistogram = 4,
  colourDensity   = 2,
  colourBoxPlot   = 4)
